<div id="imagingApp" v-cloak>
    <div class="d-flex align-items-center pb-2">
        <h4 class="font-weight-bold m-0 font-size-14"><i class="fa fa-image mr-2"></i>Imaging</h4>
        <span class="mx-2 text-secondary">|</span>
        <a class="py-0 font-weight-normal c-pointer" v-on:click.prevent="showPopup('imaging-popup')">Add</a>
    </div>
    <table class="table table-sm table-bordered mb-0" style="table-layout: fixed">
        <thead>
        <tr>
            <th class="px-2 text-secondary border-bottom-0 width-30px">#</th>
            <th class="px-2 text-secondary border-bottom-0">Tests</th>
            <th class="px-2 text-secondary border-bottom-0">ICDs</th>
            <th class="px-2 text-secondary border-bottom-0">Memo</th>
            <th class="px-2 text-secondary border-bottom-0">&nbsp;</th>
        </tr>
        </thead>
        <tbody>
        <tr v-for="(item, index) in items" :class="item.is_open ? '' : 'opacity-60'">
            <td class="px-2">#</td>
            <td class="px-2" v-html="item.tests && Array.isArray(item.tests) ? item.tests.join('<br>') : item.tests"></td>
            <td class="px-2" v-html="item.icds && Array.isArray(item.icds) ? item.icds.join('<br>') : item.icds"></td>
            <td class="px-2">@{{item.memo}}</td>
            <td class="px-2 text-nowrap">
                <a class="mr-2 c-pointer" v-on:click.prevent="showPopup('imaging-popup', item)">Edit</a>
                <a class="mr-2 c-pointer" v-if="item.is_open" v-on:click.prevent="closeItem(item)">Close</a>
                <a class="mr-2 c-pointer" v-if="!item.is_open" v-on:click.prevent="openItem(item)">Open</a>
            </td>
        </tr>
        </tbody>
    </table>
    <div class="stag-popup stag-popup-sm mcp-theme-1" stag-popup-key="imaging-popup">
        <form method="POST" action="/api/appointment/create" class="overflow-visible">
            <h3 class="stag-popup-title mb-2">
                <span>@{{ popupMode === 'add' ? 'Add Imaging Order Item' : 'Edit Imaging Order Item' }}</span>
                <a href="#" class="ml-auto text-secondary"
                   onclick="return closeStagPopup()"><i class="fa fa-times-circle"></i></a>
            </h3>
            <div class="mb-2">
                <div class="d-flex align-items-center mb-1">
                    <label class="text-sm text-secondary mb-0">Tests</label>
                    <span class="text-sm mx-2 text-secondary">|</span>
                    <a href="#" class="text-sm" v-on:click.prevent="popupItem.tests.push('')">Add</a>
                </div>
                <div class="d-flex align-items-center mb-2" v-for="(test, testIndex) in popupItem.tests">
                    <div class="position-relative flex-grow-1">
                        <input required type="text" data-option-list v-model="popupItem.tests[testIndex]" class="form-control form-control-sm">
                        <div class="data-option-list">
                            <div>CAT Scan</div>
                            <div>Fluoroscopy</div>
                            <div>MRI Scan</div>
                            <div>Mammography</div>
                            <div>X-Ray</div>
                            <div>PET</div>
                            <div>PET-CT</div>
                        </div>
                    </div>
                    <a v-if="popupItem.tests.length > 1" class="ml-2 text-danger" href="#" v-on:click.prevent="popupItem.tests.splice(testIndex, 1)">
                        <i class="fa fa-trash-alt"></i>
                    </a>
                </div>
            </div>
            <div class="mb-2">
                <div class="d-flex align-items-center mb-1">
                    <label class="text-sm text-secondary mb-0">ICDs</label>
                    <span class="text-sm mx-2 text-secondary">|</span>
                    <a href="#" class="text-sm" v-on:click.prevent="popupItem.icds.push('')">Add</a>
                </div>
                <div class="d-flex align-items-center mb-2" v-for="(icd, icdIndex) in popupItem.icds">
                    <div class="position-relative flex-grow-1">
                        <input required type="text" data-field="icd" :data-index="icdIndex"
                               v-model="popupItem.icds[icdIndex]" class="form-control form-control-sm">
                    </div>
                    <a v-if="popupItem.icds.length > 1" class="ml-2 text-danger" href="#" v-on:click.prevent="popupItem.icds.splice(icdIndex, 1)">
                        <i class="fa fa-trash-alt"></i>
                    </a>
                </div>
            </div>
            <div class="mb-2">
                <label class="text-sm text-secondary mb-1">Memo</label>
                <input type="text" v-model="popupItem.memo" class="form-control form-control-sm">
            </div>
            <div class="d-flex align-items-center justify-content-center mt-3">
                <button type="button" class="btn btn-sm btn-primary mr-2" v-on:click.prevent="savePopupItem()">Submit</button>
                <button type="button" class="btn btn-sm btn-default border" onclick="return closeStagPopup()">Cancel</button>
            </div>
        </form>
    </div>
</div>
<script>
    (function() {
        <?php
        $tickets = $patient->tickets->filter(function($_item) {
            return $_item->category === 'imaging';
        });
        $items = [];
        foreach ($tickets as $ticket) {
            $item = json_decode($ticket->data);
            $item->uid = $ticket->uid;
            $item->is_open = $ticket->is_open;
            $items[] = $item;
        }
        ?>
        function init() {
            let items = [];
            let imagingApp = new Vue({
                el: '#imagingApp',
                delimiters: ['@{{', '}}'],
                data: {
                    popupMode: 'add',
                    items: {!! json_encode($items) !!},
                    popupItem: {
                        uid: '',
                        is_open: true,
                        tests: [''],
                        icds: [''],
                        memo: '',
                    },
                },
                methods: {
                    showPopup: function(_name, _item) {
                        closeStagPopup();
                        this.popupMode = _item ? 'edit' : 'add';
                        this.popupItem = _item ? JSON.parse(JSON.stringify(_item)) : {
                            uid: '',
                            is_open: true,
                            tests: [''],
                            icds: [''],
                            memo: '',
                        };
                        let self = this;
                        Vue.nextTick(function() {
                            self.initICDAutoSuggest();
                            showStagPopup('imaging-popup', true);
                        });
                    },
                    savePopupItem: function() {
                        let form = $('#imagingApp form').first();
                        if(!form[0].checkValidity()) {
                            form[0].reportValidity();
                            return false;
                        }

                        showMask();
                        let payload = {};
                        if(this.popupMode === 'add') {
                            payload.clientUid = '{{ $patient->uid }}';
                            payload.category = 'imaging';
                            payload.assignedProUid = '{{ $pro->uid  }}';
                            payload.managerProUid = '{{ $pro->uid  }}';
                            payload.orderingProUid = '{{ $pro->uid  }}';
                            payload.initiatingProUid = '{{ $pro->uid  }}';
                            payload.data = JSON.stringify(this.popupItem);
                        }
                        else {
                            payload.uid = this.popupItem.uid;
                            payload.newData = JSON.stringify(this.popupItem);
                        }

                        $.post(
                            '/api/ticket/' + (this.popupMode === 'add' ? 'create' : 'updateData'),
                            payload,
                            function(_data) {
                                console.log(_data);
                                fastReload();
                            },
                            'json');

                        return false;
                    },
                    closeItem: function(_item) {
                        showMask();
                        $.post('/api/ticket/close', {
                            uid: _item.uid
                        }, function(_data) {
                            fastReload();
                        });
                    },
                    openItem: function(_item) {
                        showMask();
                        $.post('/api/ticket/open', {
                            uid: _item.uid
                        }, function(_data) {
                            fastReload();
                        });
                    },
                    initICDAutoSuggest: function() {
                        let self = this;
                        $('#imagingApp input[type="text"][data-field="icd"]:not([ac-initialized])').each(function() {
                            var elem = this,
                                dynID = 'icd-' + Math.ceil(Math.random() * 1000000),
                                vueIndex = $(this).attr('data-index');
                            $(elem).attr('id', dynID);
                            new window.Def.Autocompleter.Search(dynID,
                                'https://clinicaltables.nlm.nih.gov/api/icd10cm/v3/search?sf=code,name&ef=name', {
                                    tableFormat: true,
                                    valueCols: [0],
                                    colHeaders: ['Code', 'Name'],
                                }
                            );
                            window.Def.Autocompleter.Event.observeListSelections(dynID, function() {
                                let autocomp = elem.autocomp, acData = autocomp.getSelectedItemData();
                                self.popupItem.icds[vueIndex] = acData[0].code;
                                return false;
                            });
                            $(elem).attr('ac-initialized', 1);
                        });
                    },
                },
                mounted: function () {
                    this.initICDAutoSuggest();
                }
            })
        }
        addMCInitializer('imaging', init, '#imagingApp');
    })();
</script>
